#[repr(simd)]pub struct __m128d([f64; 2]);Expand description
128-bit wide set of two f64 types, x86-specific
This type is the same as the __m128d type defined by Intel,
representing a 128-bit SIMD register which internally is consisted of
two packed f64 instances. Usage of this type typically corresponds
to the sse and up target features for x86/x86_64.
Note that unlike __m128i, the integer version of the 128-bit
registers, this __m128d type has one interpretation. Each instance
of __m128d always corresponds to f64x2, or two f64 types packed
together.
The in-memory representation of this type is the same as the one of an equivalent array (i.e. the in-memory order of elements is the same, and there is no padding); however, the alignment is different and equal to the size of the type. Note that the ABI for function calls may not be the same.
Most intrinsics using __m128d are prefixed with _mm_ and are
suffixed with “pd” (or otherwise contain “pd”). Not to be confused with
“ps” which is used for __m128.
Examples
Tuple Fields
0: [f64; 2]Implementations