#[repr(simd)]pub struct __m128i([i64; 2]);Expand description
128-bit wide integer vector type, x86-specific
This type is the same as the __m128i type defined by Intel,
representing a 128-bit SIMD register. Usage of this type typically
corresponds to the sse and up target features for x86/x86_64.
Internally this type may be viewed as:
i8x16- sixteeni8variables packed togetheri16x8- eighti16variables packed togetheri32x4- fouri32variables packed togetheri64x2- twoi64variables packed together
(as well as unsigned versions). Each intrinsic may interpret the internal bits differently, check the documentation of the intrinsic to see how it’s being used.
The in-memory representation of this type is the same as the one of an equivalent array (i.e. the in-memory order of elements is the same, and there is no padding); however, the alignment is different and equal to the size of the type. Note that the ABI for function calls may not be the same.
Note that this means that an instance of __m128i typically just means
a “bag of bits” which is left up to interpretation at the point of use.
Most intrinsics using __m128i are prefixed with _mm_ and the
integer types tend to correspond to suffixes like “epi8” or “epi32”.
Examples
Tuple Fields
0: [i64; 2]Implementations
Sourceimpl __m128i
impl __m128i
pub(crate) const fn as_u8x16(self) -> Simd<u8, 16>
pub(crate) const fn as_u16x8(self) -> Simd<u16, 8>
pub(crate) const fn as_u32x4(self) -> Simd<u32, 4>
pub(crate) const fn as_u64x2(self) -> Simd<u64, 2>
pub(crate) const fn as_i8x16(self) -> Simd<i8, 16>
pub(crate) const fn as_i16x8(self) -> Simd<i16, 8>
pub(crate) const fn as_i32x4(self) -> Simd<i32, 4>
pub(crate) const fn as_i64x2(self) -> Simd<i64, 2>