#[repr(simd)]pub struct __m256([f32; 8]);Expand description
256-bit wide set of eight f32 types, x86-specific
This type is the same as the __m256 type defined by Intel,
representing a 256-bit SIMD register which internally is consisted of
eight packed f32 instances. Usage of this type typically corresponds
to the avx and up target features for x86/x86_64.
Note that unlike __m256i, the integer version of the 256-bit
registers, this __m256 type has one interpretation. Each instance
of __m256 always corresponds to f32x8, or eight f32 types packed
together.
The in-memory representation of this type is the same as the one of an equivalent array (i.e. the in-memory order of elements is the same, and there is no padding between two consecutive elements); however, the alignment is different and equal to the size of the type. Note that the ABI for function calls may not be the same.
Most intrinsics using __m256 are prefixed with _mm256_ and are
suffixed with “ps” (or otherwise contain “ps”). Not to be confused with
“pd” which is used for __m256d.
Examples
Tuple Fields
0: [f32; 8]Implementations