__m512h

Struct __m512h 

1.94.0 · Source
#[repr(simd)]
pub struct __m512h([f16; 32]);
Available on x86 or x86-64 only.
512-bit wide set of 32 f16 types, x86-specific

This type is the same as the __m512h type defined by Intel, representing a 512-bit SIMD register which internally is consisted of 32 packed f16 instances. its purpose is for f16 related intrinsic implementations.

The in-memory representation of this type is the same as the one of an equivalent array (i.e. the in-memory order of elements is the same, and there is no padding); however, the alignment is different and equal to the size of the type. Note that the ABI for function calls may not be the same.

Tuple Fields

0: [f16; 32]

Implementations

Source

impl __m512h

fn splat(value: f16) -> __m512h

Put the same value in every lane.

const fn as_array(&self) -> &[f16; 32]

Returns an array reference containing the entire SIMD vector.

fn as_mut_array(&mut self) -> &mut [f16; 32]

Returns a mutable array reference containing the entire SIMD vector.

Source

impl __m512h

pub(crate) const fn as_f16x32(self) -> Simd<f16, 32>