#[repr(simd)]pub struct __m512i([i64; 8]);Expand description
512-bit wide integer vector type, x86-specific
This type is the same as the __m512i type defined by Intel,
representing a 512-bit SIMD register. Usage of this type typically
corresponds to the avx512* and up target features for x86/x86_64.
Internally this type may be viewed as:
i8x64- sixty-fouri8variables packed togetheri16x32- thirty-twoi16variables packed togetheri32x16- sixteeni32variables packed togetheri64x8- eighti64variables packed together
(as well as unsigned versions). Each intrinsic may interpret the internal bits differently, check the documentation of the intrinsic to see how it’s being used.
The in-memory representation of this type is the same as the one of an equivalent array (i.e. the in-memory order of elements is the same, and there is no padding); however, the alignment is different and equal to the size of the type. Note that the ABI for function calls may not be the same.
Note that this means that an instance of __m512i typically just means
a “bag of bits” which is left up to interpretation at the point of use.
Tuple Fields
0: [i64; 8]Implementations
Sourceimpl __m512i
impl __m512i
pub(crate) const fn as_u8x64(self) -> Simd<u8, 64>
pub(crate) const fn as_u16x32(self) -> Simd<u16, 32>
pub(crate) const fn as_u32x16(self) -> Simd<u32, 16>
pub(crate) const fn as_u64x8(self) -> Simd<u64, 8>
pub(crate) const fn as_i8x64(self) -> Simd<i8, 64>
pub(crate) const fn as_i16x32(self) -> Simd<i16, 32>
pub(crate) const fn as_i32x16(self) -> Simd<i32, 16>
pub(crate) const fn as_i64x8(self) -> Simd<i64, 8>